@@ -7,7 +7,7 @@ require 5.004;
 
 use vars qw($VERSION);
 
-$VERSION = '1.03';
+$VERSION = '1.08';
 
 sub version { $VERSION; }
 
@@ -22,4 +22,15 @@ sub new {
 
 sub DESTROY { }
 
+package asterisk::perl;
+
+=head1 NAME
+
+asterisk::perl
+
+This module exists solely to satisfy packaging requirements.
+
+=cut
+
+
 1;
